@@ -4,12 +4,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 import asyncio
-
-import tempfile, os
+import concurrent.futures
+import os
+import tempfile
 
 from traitlets import Bool, default
-from jupyter_core.paths import jupyter_path
-import concurrent.futures
 
 from .html import HTMLExporter
 
@@ -20,10 +19,12 @@ class WebPDFExporter(HTMLExporter):
     This inherits from :class:`HTMLExporter`. It creates the HTML using the
     template machinery, and then run pyppeteer to create a pdf.
     """
+
     export_from_notebook = "PDF via HTML"
 
-    allow_chromium_download = Bool(False,
-        help='Whether to allow downloading Chromium if no suitable version is found on the system.'
+    allow_chromium_download = Bool(
+        False,
+        help="Whether to allow downloading Chromium if no suitable version is found on the system.",
     ).tag(config=True)
 
     paginate = Bool(
@@ -34,18 +35,16 @@ class WebPDFExporter(HTMLExporter):
         If False, a PDF with one long page will be generated.
 
         Set to True to match behavior of LaTeX based PDF generator
-        """
+        """,
     ).tag(config=True)
 
-    output_mimetype = "text/html"
-
-    @default('file_extension')
+    @default("file_extension")
     def _file_extension_default(self):
-        return '.html'
+        return ".html"
 
-    @default('template_name')
+    @default("template_name")
     def _template_name_default(self):
-        return 'webpdf'
+        return "webpdf"
 
     disable_sandbox = Bool(
         False,
@@ -60,7 +59,7 @@ class WebPDFExporter(HTMLExporter):
         has more information.
 
         This is required for webpdf to work inside most container environments.
-        """
+        """,
     ).tag(config=True)
 
     def _check_launch_reqs(self):
@@ -68,36 +67,37 @@ class WebPDFExporter(HTMLExporter):
             from pyppeteer import launch
             from pyppeteer.util import check_chromium
         except ModuleNotFoundError as e:
-            raise RuntimeError("Pyppeteer is not installed to support Web PDF conversion. "
-                               "Please install `nbconvert[webpdf]` to enable.") from e
+            raise RuntimeError(
+                "Pyppeteer is not installed to support Web PDF conversion. "
+                "Please install `nbconvert[webpdf]` to enable."
+            ) from e
         if not self.allow_chromium_download and not check_chromium():
-            raise RuntimeError("No suitable chromium executable found on the system. "
-                               "Please use '--allow-chromium-download' to allow downloading one.")
+            raise RuntimeError(
+                "No suitable chromium executable found on the system. "
+                "Please use '--allow-chromium-download' to allow downloading one."
+            )
         return launch
 
     def run_pyppeteer(self, html):
         """Run pyppeteer."""
 
         async def main(temp_file):
-            args = ['--no-sandbox'] if self.disable_sandbox else []
+            args = ["--no-sandbox"] if self.disable_sandbox else []
             browser = await self._check_launch_reqs()(
-                handleSIGINT=False,
-                handleSIGTERM=False,
-                handleSIGHUP=False,
-                args=args
+                handleSIGINT=False, handleSIGTERM=False, handleSIGHUP=False, args=args
             )
             page = await browser.newPage()
-            await page.emulateMedia('screen')
+            await page.emulateMedia("print")
             await page.waitFor(100)
-            await page.goto(f'file://{temp_file.name}', waitUntil='networkidle0')
+            await page.goto(f"file://{temp_file.name}", waitUntil="networkidle0")
             await page.waitFor(100)
 
-            pdf_params = {'printBackground': True}
+            pdf_params = {"printBackground": True}
             if not self.paginate:
                 # Floating point precision errors cause the printed
                 # PDF from spilling over a new page by a pixel fraction.
                 dimensions = await page.evaluate(
-                """() => {
+                    """() => {
                     const rect = document.body.getBoundingClientRect();
                     return {
                     width: Math.ceil(rect.width) + 1,
@@ -105,13 +105,15 @@ class WebPDFExporter(HTMLExporter):
                     }
                 }"""
                 )
-                width = dimensions['width']
-                height = dimensions['height']
+                width = dimensions["width"]
+                height = dimensions["height"]
                 # 200 inches is the maximum size for Adobe Acrobat Reader.
-                pdf_params.update({
-                    'width': min(width, 200 * 72),
-                    'height': min(height, 200 * 72),
-                })
+                pdf_params.update(
+                    {
+                        "width": min(width, 200 * 72),
+                        "height": min(height, 200 * 72),
+                    }
+                )
             pdf_data = await page.pdf(pdf_params)
 
             await browser.close()
@@ -125,7 +127,7 @@ class WebPDFExporter(HTMLExporter):
         # file is not deleted after closing (the default behavior).
         temp_file = tempfile.NamedTemporaryFile(suffix=".html", delete=False)
         with temp_file:
-            temp_file.write(html.encode('utf-8'))
+            temp_file.write(html.encode("utf-8"))
         try:
             # TODO: when dropping Python 3.6, use
             # pdf_data = pool.submit(asyncio.run, main(temp_file)).result()
@@ -133,6 +135,7 @@ class WebPDFExporter(HTMLExporter):
                 loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(loop)
                 return loop.run_until_complete(coro)
+
             pdf_data = pool.submit(run_coroutine, main(temp_file)).result()
         finally:
             # Ensure the file is deleted even if pypeteer raises an exception
@@ -141,17 +144,14 @@ class WebPDFExporter(HTMLExporter):
 
     def from_notebook_node(self, nb, resources=None, **kw):
         self._check_launch_reqs()
-        html, resources = super().from_notebook_node(
-            nb, resources=resources, **kw
-        )
+        html, resources = super().from_notebook_node(nb, resources=resources, **kw)
 
-        self.log.info('Building PDF')
+        self.log.info("Building PDF")
         pdf_data = self.run_pyppeteer(html)
-        self.log.info('PDF successfully created')
+        self.log.info("PDF successfully created")
 
         # convert output extension to pdf
         # the writer above required it to be html
-        resources['output_extension'] = '.pdf'
+        resources["output_extension"] = ".pdf"
 
         return pdf_data, resources
-
